@@ -23,8 +23,6 @@ import re
 
 from datetime import timezone
 
-from typing import Any
-from typing import Dict
 from typing import Generator
 from typing import Optional
 from typing import TypeVar
@@ -117,7 +115,9 @@ def to_camel_case(obj: T) -> T:
     if isinstance(obj, dict):
         aux = dict()
         for key, value in obj.items():
-            new_key = re.sub(r"(?<=.{1})_([a-z])", lambda m: f"{m.group(1).upper()}", key)
+            new_key = re.sub(
+                r"(?<=.{1})_([a-z])", lambda m: f"{m.group(1).upper()}", key
+            )
             aux[new_key] = to_camel_case(value)
 
         return aux  # type: ignore
@@ -130,7 +130,9 @@ def to_snake_case(obj: T) -> T:
     if isinstance(obj, dict):
         aux = dict()
         for key, value in obj.items():
-            new_key = re.sub(r"(?<=.{1})([A-Z])", lambda m: f"_{m.group(0)}", key).lower()
+            new_key = re.sub(
+                r"(?<=.{1})([A-Z])", lambda m: f"_{m.group(0)}", key
+            ).lower()
             aux[new_key] = to_snake_case(value)
 
         return aux  # type: ignore
